@@ -3,13 +3,12 @@
 """
 import argparse
 import logging
+import os.path
 
 from git import Repo
 from notebuild.core.version import VersionManage
 from notebuild.shell import run_shell, run_shell_list
 
-logger = logging.getLogger("notebuild")
-
 
 class PackageBuild:
     """
@@ -29,7 +28,7 @@ class PackageBuild:
         """
         git pull
         """
-        logger.info("{} pull".format(self.name))
+        logging.info("{} pull".format(self.name))
         # run_shell("git pull")
         self.repo.remote().pull()
 
@@ -37,7 +36,7 @@ class PackageBuild:
         """
         git push
         """
-        logger.info("{} push".format(self.name))
+        logging.info("{} push".format(self.name))
         run_shell_list([
             'git add -A',
             'git commit -a -m "add"',
@@ -51,7 +50,7 @@ class PackageBuild:
         """
         git install
         """
-        logger.info('{} install'.format(self.name))
+        logging.info('{} install'.format(self.name))
         run_shell_list([
             'pip uninstall {} -y'.format(self.name),
             'python3 setup.py install',
@@ -66,10 +65,10 @@ class PackageBuild:
         pip install
         """
         run_shell('pip install -U -q git+{}'.format(self.git_url))
-        logger.info('pip install {} success'.format(self.name))
+        logging.info('pip install {} success'.format(self.name))
 
     def git_clear_build(self):
-        logger.info('{} build clear'.format(self.name))
+        logging.info('{} build clear'.format(self.name))
         run_shell_list([
             'rm -rf {}.egg-info'.format(self.name),
             'rm -rf dist',
@@ -80,16 +79,22 @@ class PackageBuild:
         """
         git build
         """
-        logger.info('{} build'.format(self.name))
+        logging.info('{} build'.format(self.name))
         self.git_pull()
         self.git_clear_build()
         self.version_manage.add()
         self.version_manage.write()
+        set_up_file = 'setup.py'
+        if not os.path.exists(set_up_file):
+            set_up_file = 'setup2.py'
+        if not os.path.exists(set_up_file):
+            set_up_file = 'setup3.py'
+
         run_shell_list([
-            'python3 setup.py build',  # 编译
-            'python3 setup.py sdist',  # 生成 tar.gz
-            'python3 setup.py bdist_egg',  # 生成 egg 包
-            'python3 setup.py bdist_wheel',  # 生成 wheel 包
+            f'python3 {set_up_file} build',  # 编译
+            f'python3 {set_up_file} sdist',  # 生成 tar.gz
+            f'python3 {set_up_file} bdist_egg',  # 生成 egg 包
+            f'python3 {set_up_file} bdist_wheel',  # 生成 wheel 包
 
             # twine register dist/*
             'twine upload dist/*'  # 发布包
@@ -103,7 +108,7 @@ class PackageBuild:
         """
         git build
         """
-        logger.info('{} clean history'.format(self.name))
+        logging.info('{} clean history'.format(self.name))
         run_shell_list([
             'git checkout --orphan latest_branch',  # 1.Checkout
             'git add -A',  # 2. Add all the files
@@ -117,7 +122,7 @@ class PackageBuild:
         """
         git clean
         """
-        logger.info('{} clean'.format(self.name))
+        logging.info('{} clean'.format(self.name))
         run_shell_list([
             'git rm -r --cached .',
             'git add .',
@@ -156,3 +161,17 @@ def notebuild():
         package.git_clean()
     elif args.command == 'clean_history':
         package.git_clean_history()
+    elif args.command == 'tags':
+        package.git_tags()
+    elif args.command == 'help':
+        info = """
+build 
+pull
+push
+install
+clean
+clean_history
+help
+tags
+        """
+        print(info)
